<?

/************************************************************************/
/* FlatNuke - Flat Text Based Content Management System                 */
/* ============================================                         */
/*                                                                      */
/* Copyright (c) 2003 by Simone Vellei                                  */
/* http://flatnuke.sourceforge.net                                      */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


if (eregi("cerca.php",$_SERVER['PHP_SELF'])) {
    Header("Location: ../../index.php");
    die();
}

// configuration
$search_plugins_dir = "include/search/";
$GLOBALS['search_plugins_dir'] = $search_plugins_dir;
$search_section = "none_Search";

?>
<div style="text-align:center; margin-bottom:0.5em;">
<form action="index.php?mod=<?=$search_section?>" method="post">
	<input type="hidden" name="method" value="AND" />
	<input type="hidden" name="mod" value="<?=$search_section?>" />
	<input type="hidden" name="where" value="allsite" />
	<input type="text" name="find" size="10" id="text" />
	<input type="submit" value="<?=_CERCA?>" />
</form>
</div>
<div style="margin-bottom:0.5em;">
<?=_SEARCHDESC?>
</div>
<div style="text-align:center">
<a href="index.php?mod=<?=$search_section?>" title="<?=_GOTOSECTION?>: <?=_CERCA?>"><?=_ADVSEARCH?></a>
</div>
